/*---------------------------------------------------------------------------*\
  =========                 |
  \\      /  F ield         | OpenFOAM: The Open Source CFD Toolbox
   \\    /   O peration     |
    \\  /    A nd           | Copyright (C) 1991-2010 OpenCFD Ltd.
     \\/     M anipulation  |
-------------------------------------------------------------------------------
License
    This file is part of OpenFOAM.

    OpenFOAM is free software: you can redistribute it and/or modify it
    under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    OpenFOAM is distributed in the hope that it will be useful, but WITHOUT
    ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
    FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
    for more details.

    You should have received a copy of the GNU General Public License
    along with OpenFOAM.  If not, see <http://www.gnu.org/licenses/>.

Class
    Foam::griemannHollyModel

Description

SourceFiles
    griemannHollyModel.C

\*---------------------------------------------------------------------------*/

#ifndef griemannHollyModel_H
#define griemannHollyModel_H

#include "phaseModel.H"
#include "autoPtr.H"
#include "fvCFD.H"
// * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * //

namespace Foam
{

/*---------------------------------------------------------------------------*\
                           Class griemannHollyModel Declaration
\*---------------------------------------------------------------------------*/

class griemannHollyModel
{
    // Private data

        const phaseModel& phasea_;
        const volVectorField& Ua_;
        const volScalarField& alpha_;
        const surfaceScalarField& phia_;
        const dimensionedScalar& rhoa_;
        const dimensionedScalar& da_;
        const dimensionedScalar& nua_;

        //- dictionary holding the modeling info
        IOdictionary griemannHollyProperties_;

        //- use kinetic theory or not.
        Switch griemannHolly_;

        //- Use nuta = nutb.
        Switch turbulentViscosityb_;

        //- coefficient of restitution
        const dimensionedScalar e_;

        //- angle of internal friction
        const dimensionedScalar phi_;

        //- The granular energy/temperature
        volScalarField Theta_;

        //- The granular viscosity
        volScalarField mua_;

        volScalarField muf_;

        //- The granular bulk viscosity
        volScalarField lambda_;

        //- The granular pressure
        volScalarField pa_;

        //- frictional stress
        volScalarField pf_;

        //- The radial distribution function
        volScalarField gs0_;


    // Private Member Functions

        //- Disallow default bitwise copy construct
        griemannHollyModel(const griemannHollyModel&);

        //- Disallow default bitwise assignment
        void operator=(const griemannHollyModel&);


public:

    // Constructors

        //- Construct from components
        griemannHollyModel
        (
            const phaseModel& phasea
        );


    //- Destructor
    virtual ~griemannHollyModel();


    // Member Functions

        void update(const volScalarField& kb, const volScalarField& nutb);

        bool on() const
        {
            return griemannHolly_;
        }

        const volScalarField& Theta() const
        {
            return Theta_;
        }        

        const volScalarField& mua() const
        {
            return mua_;
        }

        const volScalarField& muf() const
        {
            return muf_;
        }

        const volScalarField& pa() const
        {
            return pa_;
        }
 
        const volScalarField& pf() const
        {
            return pf_;
        }      

        const volScalarField& lambda() const
        {
            return lambda_;
        }

        const dimensionedScalar& phi() const
        {
            return phi_;
        }
    
};


// * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * //

} // End namespace Foam

// * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * //

#endif

// ************************************************************************* //
